componenttools.partition_components_by_durations_le
===================================================

.. autofunction:: abjad.tools.componenttools.partition_components_by_durations_le.partition_components_by_durations_le
